#ifndef SSLLABEL_H
#define SSLLABEL_H

/*
  Copyright (c) 2004 by İsmail Dönmez <ismail.donmez@boun.edu.tr>

  *************************************************************************
  *                                                                       *
  * This program is free software; you can redistribute it and/or modify  *
  * it under the terms of the GNU General Public License as published by  *
  * the Free Software Foundation; either version 2 of the License, or     *
  * (at your option) any later version.                                   *
  *                                                                       *
  *************************************************************************

 */

#include <tqlabel.h>

class SSLLabel : public TQLabel
{
    TQ_OBJECT
  

        public:
        SSLLabel(TQWidget* parent, const char* name);

    protected:
        void mouseReleaseEvent(TQMouseEvent *e);

        signals:
        void clicked();
};
#endif
